Learn R Programming

sinar (version 0.1.0)

carabidae: Counts of arthropods in a grid-sampled wheat field

Description

A matrix with the counts of arthropods (carabidae) in a grid-sampled wheat field

Usage

data("carabidae")

Arguments

Format

A matrix where each row and column is a count of carabidae species at the first cell.