Learn R Programming

sinar (version 0.1.0)

sinar_pois: Simulating SINAR(1,1) process with innovations from a poison distribution.

Description

sinar_pois returns a matrix representing a simulated regular lattice from a SINAR(1,1) process with innovations from a poison distribution.

Usage

sinar_pois(n_row, n_col, a10, a01, a11, l)

Arguments

n_row

Number of rows in the simulated lattice.

n_col

Number of columns in the simulated lattice.

a10

Coefficient from the element \(X_{i-1, j}\).

a01

Coefficient from the element \(X_{i, j-1}\).

a11

Coefficient from the element \(X_{i-1, j-1}\).

l

Mean of the poison distribution used as innovations.

Value

A integer matrix.

Details

This function simulates a regular lattice from the model $$X_{i,j}= a_{10} X_{i-1,j} + a_{01} X_{i,j-1} + a_{11} X_{i-1, j-1} + \epsilon_{i,j}$$ where \(\epsilon_{i,j}\) is an iid process with poison distribution. Note the \(a_{10}, a_{01}, a_{11}\) must belong to the interval \([0,1]\).

Examples

Run this code
# NOT RUN {
n_row <- 20
n_col <- 50
a10 <- 0.2
a01 <- 0.2
a11 <-  0.5
l <- 1
sinar_pois(n_row, n_col, a10, a01, a11, l)
# }

Run the code above in your browser using DataLab